# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from abc import abstractmethod
from ubuntu_system_tests.helpers.ubuntuuitools.cpo.slider import Slider
from ubuntu_system_tests.helpers.ubuntuuitools.cpo.common import CustomProxyObjectBase  # NOQA


class BrightnessPageBase(CustomProxyObjectBase):

    @classmethod
    def validate_dbus_object(cls, path, state):
        return False

    def _get_brightness_switch(self):
        """Return the auto brightness switch."""
        return self.select_single('SwitchMenu',
                                  objectName='indicator.auto-brightness')

    def get_brightness_slider_widget(self):
        """Return the slider widget on the battery indicator page."""
        return self.select_single(Slider, objectName='slider')

    def get_current_brightness(self):
        return float(self.get_brightness_slider_widget().value)

    @abstractmethod
    def get_auto_adjust_checkbox(self):
        pass

    @abstractmethod
    def get_max_brightness(self):
        pass

    def is_auto_adjust_enabled(self):
        """Return checked state of auto adjust switch."""
        return self.get_auto_adjust_checkbox().checked

    def toggle_auto_adjust(self):
        """Press the auto adjust switch and wait for state to change."""
        original_state = self.is_auto_adjust_enabled()
        self.pointing_device.click_object(self.get_auto_adjust_checkbox())
        self.get_auto_adjust_checkbox().checked.wait_for(not original_state)

    def enable_auto_brightness(self):
        """Enable auto brightness."""
        if not self.is_auto_adjust_enabled():
            self.toggle_auto_adjust()

    def disable_auto_brightness(self):
        """Disable auto brightness."""
        if self.is_auto_adjust_enabled():
            self.toggle_auto_adjust()
