# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from dbus.mainloop.glib import DBusGMainLoop
from gi.repository import GLib

from ubuntu_system_tests.helpers.observer import Observer


class DBusObserver(Observer):
    """Base class for a DBus observer object."""

    def __init__(self, stop, result):
        """
        Construct the Observer object.
        :param stop: Event object to signal when to stop waiting.
        :param result: Event object to signal when result is matched.

        """
        super().__init__(stop, result)
        DBusGMainLoop(set_as_default=True)
        self._mainloop = GLib.MainLoop()

    def start(self):
        """
        Start the observer by starting the callback timer and the glib
        mainloop.

        """
        super().start()
        self._mainloop.run()

    def stop(self):
        """Stop the glib mainloop to stop observing."""
        self._mainloop.quit()
        super().stop()
