# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Copyright (C) 2016 Canonical Ltd.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation; version 3.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import fixtures

from ubuntu_system_tests.helpers.backup_restore_fixture import (
    BackupRestoreFixture)
from ubuntu_system_tests.helpers import file_system as fs


class DekkoEnvironmentFixture(fixtures.Fixture):

    def setUp(self):
        super().setUp()
        self.useFixture(BackupRestoreDekkoData(start_clean=True))
        self.useFixture(BackupRestoreDekkoConfig(start_clean=True))


class BackupRestoreDekkoData(fixtures.Fixture):
    """Generic fixture class to backup and restore dekko data."""

    def __init__(self, start_clean=True):
        """
        :param start_clean: Whether to clean directories after backup.

        """
        self.start_clean = start_clean

    def setUp(self):
        """Backup the required directory and register restore actions."""
        super().setUp()
        self._backup_files()

    def _backup_files(self):
        """Backup the files which are removed during testing."""
        self.useFixture(BackupRestoreFixture(fs.DIR_HOME_LOCAL_SHARE_DEKKO,
                                             start_clean=self.start_clean))


class BackupRestoreDekkoConfig(fixtures.Fixture):
    """Generic fixture class to backup and restore dekko config."""

    def __init__(self, start_clean=True):
        """
        :param start_clean: Whether to clean directories after backup.

        """
        self.start_clean = start_clean

    def setUp(self):
        """Backup the required directory and register restore actions."""
        super().setUp()
        self._backup_files()

    def _backup_files(self):
        """Backup the files which are removed during testing."""
        self.useFixture(BackupRestoreFixture(fs.DIR_HOME_DEKKO_CONFIG,
                                             start_clean=self.start_clean))
