# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
import fixtures
from ubuntu_system_tests.helpers.init_systems import get_init_system


class JobEnvironmentVariable(fixtures.Fixture):
    """ Class used to set an environment variable for a job during the
    test execution. This Fixture could use either upstart or systemd
    depending the machine/device where it is executed.
    """

    def __init__(self, global_=False, **kwargs):
        super().__init__()
        self.variables = kwargs
        self.global_ = global_

    def setUp(self):
        super().setUp()
        init_system = get_init_system()
        for key, value in self.variables.items():
            init_system.set_environment_variable(key, value, self.global_)
            self.addCleanup(init_system.unset_environment_variable,
                            key, value, self.global_)
