# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
import fixtures
import os

from ubuntu_system_tests.helpers.indicators.network.job import (
    IndicatorNetworkInitSystem)
from ubuntu_system_tests.helpers import network
from ubuntu_system_tests.helpers.testbed import run_command_with_sudo, NM_PATH


class TurnOffInternet(fixtures.Fixture):
    """Fixture to turn off internet on the device."""

    def setUp(self):
        super().setUp()
        self.useFixture(TurnOffWifi())
        self.useFixture(TurnOffDataConnection())


class TurnOffWifi(fixtures.Fixture):
    """Fixture to turn off wifi on the device."""

    def setUp(self):
        super().setUp()
        network.turn_off_wifi()
        self.addCleanup(network.turn_on_wifi)


class TurnOffDataConnection(fixtures.Fixture):
    """Fixture to turn off data connection on the device."""

    def setUp(self):
        super().setUp()
        network.turn_off_data_connection()
        self.addCleanup(network.turn_on_data_connection)


class RemoveNetworks(fixtures.Fixture):
    """Removes all networks from the device

    Removes all networks from the device and restarts
    network services to action that change and on cleanup
    restores the previous state
    """

    def __init__(self):
        super().__init__()
        self.indicator_job = IndicatorNetworkInitSystem()

    def setUp(self):
        super().setUp()
        # only backup networks if one already exists
        if self.is_network_present():
            self.tmpdir_fixture = fixtures.TempDir()
            self.useFixture(self.tmpdir_fixture)
            run_command_with_sudo('mv {}/* {}/'.format(
                NM_PATH, self.tmpdir_fixture.path))
            # If we succesfully move the connection files
            # then we need to make sure to reinstate them
            self.addCleanup(self._restore_networks)
            run_command_with_sudo('service network-manager restart')
            self.indicator_job.restart()

    def _restore_networks(self):
        run_command_with_sudo('mv {}/* {}'.format(
            self.tmpdir_fixture.path, NM_PATH))
        run_command_with_sudo('service network-manager restart')
        self.indicator_job.restart()

    def is_network_present(self):
        """Return True if a network is currently present."""
        return len(os.listdir(NM_PATH)) > 0
