# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3,
# as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging

from autopilot.introspection import is_element

from ubuntu_system_tests.helpers.notifications.sim_lockscreen import (
    Notification,
)
from ubuntu_system_tests.helpers.ofono.utils import get_number_of_modems

logger = logging.getLogger(__name__)

SIM_PUK_POPUP_START = 'Sorry, your SIM'
SIM_PUK_POPUP_END = ('is now blocked. Please enter your PUK code to unblock '
                     'SIM card. You may need to contact your network provider '
                     'for PUK code.')
SIM_PUK_SUMMARY_START = 'Enter PUK code'
SIM_PUK_SUMMARY_END = 'for SIM'


def get_expected_popup_title(sim_number):
    """Return the expected title for a sim puk popup notification screen.
    This will depend on the number of the modems the device has and which sim
    is being requested.
    :param sim_number: Integer index for sim starting from 0.
    :return: Expected title string.
    """
    if get_number_of_modems() > 1:
        return '{} {} {}'.format(
            SIM_PUK_POPUP_START, str(sim_number + 1), SIM_PUK_POPUP_END)
    else:
        return '{} {}'.format(SIM_PUK_POPUP_START, SIM_PUK_POPUP_END)


def get_expected_title(sim_number):
    """Return the expected title for a sim puk entry screen.
    This will depend on the number of the modems the device has and which sim
    is being requested.
    :param sim_number: Integer index for sim starting from 0.
    :return: Expected title string.
    """
    if get_number_of_modems() > 1:
        return '{} {} {}'.format(
            SIM_PUK_SUMMARY_START, SIM_PUK_SUMMARY_END, str(sim_number + 1))
    else:
        return SIM_PUK_SUMMARY_START


def validate(notification):
    """
    Return True if notification object is valid and looks like a sim puk
    notification.

    Note this is implemented as a static method because it is reliable
    in cases where multiple notifications are displayed and autopilot CPO
    inheritance fails.

    :param notification: The notification object to validate.

    """
    puk_end_msg = SIM_PUK_SUMMARY_END if get_number_of_modems() > 1 else ''
    if notification and isinstance(notification, Notification):
        return (is_element(notification.get_lockscreen) and
                notification.summary.startswith(SIM_PUK_SUMMARY_START) and
                # ignore the sim number and space at the end of the message
                notification.summary[:-2].endswith(puk_end_msg))
    return False
