# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import fixtures

from ubuntu_system_tests.helpers.brightness.sensors_utils import \
    RepowerdSensors
from ubuntu_system_tests.helpers.fixture_setup import EnableFakeSensors
from ubuntu_system_tests.helpers.power import RepowerdJob
from ubuntu_system_tests.helpers.power import utils as power

GSETTINGS_BRIGHTNESS_MAX = 255


class BrightnessEnvironmentFixture(fixtures.Fixture):

    def __init__(self, auto_brightness='disable',
                 brightness_value=GSETTINGS_BRIGHTNESS_MAX):
        self.auto_brightness = auto_brightness
        self.brightness_value = str(brightness_value)

    def setUp(self):
        super().setUp()
        self.useFixture(AutoBrightness(state=self.auto_brightness))
        self.useFixture(Brightness(value=self.brightness_value))


class AutoBrightness(fixtures.Fixture):

    def __init__(self, state):
        self.request = state

    def setUp(self):
        super().setUp()
        old_value = power.get_auto_brightness_current_setting()
        self.addCleanup(power.set_auto_brightness_setting, old_value)

        if self.request == 'enable':
            power.set_auto_brightness_setting('true')
        elif self.request == 'disable':
            power.set_auto_brightness_setting('false')


class Brightness(fixtures.Fixture):
    """Fixture to set custom screen brightness."""

    def __init__(self, value):
        self.value = value

    def setUp(self):
        super().setUp()
        old_value = power.get_display_brightness()
        power.set_display_brightness(self.value)
        self.addCleanup(power.set_display_brightness, old_value)


class EnableRepowerdFakeSensors(EnableFakeSensors):
    """Fixture to enable fake sensors for repowerd."""
    def __init__(self):
        super().__init__(RepowerdJob(), RepowerdSensors())
