# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
import shlex
import subprocess

import dbus

GSETTINGS_BRIGHTNESS_MAX = 255


def get_auto_brightness_current_setting():
    """Return current auto brightness state from gsettings."""
    command = 'gsettings get com.ubuntu.touch.system auto-brightness'
    return subprocess.check_output(shlex.split(command),
                                   universal_newlines=True).strip()


def set_auto_brightness_setting(value):
    """Change auto brightness from gsettings."""
    command = 'gsettings set com.ubuntu.touch.system ' \
              'auto-brightness {}'.format(value)
    return subprocess.check_call(shlex.split(command))


def set_brightness_setting(value):
    """Set brightness through repowerd, value should be between 10 and 255."""
    command = 'gsettings set com.ubuntu.touch.system brightness {}'.format(
        value)
    subprocess.check_call(shlex.split(command),
                          stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)


def _get_power_actions_interface():
    bus = dbus.SessionBus()
    obj = bus.get_object('com.canonical.indicator.power',
                         '/com/canonical/indicator/power')
    return dbus.Interface(obj, 'org.gtk.Actions')


def set_display_brightness(value):
    """
    Sets the display brightness using the dbus api
    :param value: value between 0 and 1
    """
    _get_power_actions_interface().SetState(
        'brightness', float(value), [])


def get_display_brightness():
    """
    Gets the display brightness using the dbus api
    returns value between 0 and 1
    """
    return float(_get_power_actions_interface().Describe(
        'brightness')[2][0])


def get_brightness_setting():
    """Return the current brightness setting value from gsettings."""
    command = 'gsettings get com.ubuntu.touch.system brightness'
    return subprocess.check_output(shlex.split(command),
                                   universal_newlines=True).strip()
