# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from autopilot import introspection

from ubuntu_system_tests.helpers.autopilot import (
    get_patched_registry, patched_select_single, validate_dbus_object)
from ubuntu_system_tests.helpers.autopilot.list import KEY_ORDER_BY_Y
from ubuntu_system_tests.helpers.scopes.base import \
    GenericScopeView as BaseGenericScopeView
from ubuntu_system_tests.helpers.unity8.utils import UNITY8_DASH_PATH_ROOT

APP_STORE_TITLE = 'Ubuntu Store'


class GenericScopeView(BaseGenericScopeView):

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, UNITY8_DASH_PATH_ROOT, b'GenericScopeView',
            objectName='clickscope')

    def go_to_store(self):
        """Over-ride base class implementation to import required CPO."""
        from ubuntu_system_tests.helpers.scopes.apps import _app_store
        registry = get_patched_registry(
            _app_store.GenericScopeView, 'GenericScopeView')
        with introspection._object_registry.patch_registry(registry):
            store = super().go_to_store()
        self.wait_for_processing_to_complete()
        return store

    def open_preview(self, category, app_name, press_duration=0.10,
                     subtitle=None):
        """Over-ride base class to import the required CPO.
        :parameter category: The name of the category where the application is.
        :parameter app_name: The name of the application.
        :param press_duration: How long to press icon for.
        :param subtitle: Subtitle additionally used to identify required icon.
        :return: The opened preview.
        """
        from ubuntu_system_tests.helpers.scopes.apps import _preview
        self.click_scope_item(category, app_name, press_duration, subtitle)
        preview_list = self.wait_select_single(objectName='subPageLoader')
        preview_list.subPageShown.wait_for(True)
        preview_list.x.wait_for(0)
        self.wait_for_processing_to_complete()
        return patched_select_single(
            root=preview_list, class_object=_preview.Preview,
            class_name='Preview', objectName='preview')

    def get_app_icon(self, app_name):
        """Return icon for required app_name."""
        return self.wait_select_many(
            'UCAbstractButton', ap_result_sort_keys=KEY_ORDER_BY_Y,
            title=app_name)[0]

    def is_app_displayed(self, app_name):
        """Return True if app with specified name is displayed."""
        try:
            self.get_app_icon(app_name)
            return True
        except ValueError:
            return False

    def get_app_category(self, app_name):
        """Return the category name for a specified app_name."""
        app = self.get_app_icon(app_name)
        return app.get_parent('CardGrid').objectName
