# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from autopilot.introspection import is_element
from ubuntu_system_tests.helpers.ubuntuuitools.cpo.common import CustomProxyObjectBase  # NOQA
from ubuntu_system_tests.helpers.autopilot import validate_dbus_object
from ubuntu_system_tests.helpers.autopilot.list import KEY_ORDER_BY_X
from ubuntu_system_tests.helpers.unity8.utils import UNITY8_DASH_PATH_ROOT


class DashCategoryBase(CustomProxyObjectBase):
    """This class represent the Dash Category Base."""

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, UNITY8_DASH_PATH_ROOT, b'DashCategoryBase')

    def get_see_all(self):
        """ Retrieve the "see all" button """
        return self.select_single('UCLabel', text='See all', visible=True)

    def get_see_less(self):
        """ Retrieve the "see less" button """
        return self.select_single('UCLabel', text='See less', visible=True)

    def get_pictures_list(self):
        """ Retrieve all the pictures displayed currently in the list """
        return self.select_many(
            'CroppedImageMinimumSourceSize',
            ap_result_sort_keys=KEY_ORDER_BY_X, objectName='artImage')

    def is_see_all_displayed(self):
        """ Indicate if there is at least a button with text "See all" """
        return is_element(self.get_see_all)

    def is_see_less_displayed(self):
        """ Indicate if there is at least a button with text "See less" """
        return is_element(self.get_see_less)

    def is_not_see_less_displayed(self):
        """ Indicate if there are not any "See less" button being displayed """
        return not self.is_see_less_displayed()

    def get_grid(self):
        return self.select_single('QQuickGridView', visible=True)
