# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
from autopilot import platform
from ubuntu_system_tests.helpers.ubuntu_keyboard import get_keyboard
from ubuntu_system_tests.helpers.ubuntuuitools.cpo.textfield import TextField  # NOQA
from ubuntu_system_tests.helpers.ubuntuuitools.cpo.common import CustomProxyObjectBase  # NOQA

from ubuntu_system_tests.helpers.autopilot import validate_dbus_object
from ubuntu_system_tests.helpers.ubuntuuitools.cpo.flickable import QQuickFlickable  # NOQA

APP_PATH_ROOT = b'online-accounts-ui'


class OnlineAccountsUI(CustomProxyObjectBase):

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, APP_PATH_ROOT, APP_PATH_ROOT)

    @property
    def accounts_creation_page(self):
        page = self.select_single(AccountCreationPage)
        page.visible.wait_for(True)
        return page


class AccountCreationPage(CustomProxyObjectBase):

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, APP_PATH_ROOT, b'AccountCreationPage')

    def move_item_into_view(self, item):
        self._get_flickable().swipe_child_into_view(item)

    def _get_flickable(self):
        return self.select_single(Main)

    def _get_new_password_textfield(self):
        return self.select_single(objectName='newPasswordTextField')

    def _get_confirm_password_textfield(self):
        return self.select_single(objectName='confirmPasswordTextField')

    def _get_terms_checkbox(self):
        return self.select_single(objectName='termsAndConditionsCheckBox')

    def _enter_password_new_user(self, password):
        password_field = self._get_new_password_textfield()
        self.move_item_into_view(password_field)
        password_field.write(password)

    def _enter_password_confirmation(self, password):
        password_field = self._get_confirm_password_textfield()
        self.move_item_into_view(password_field)
        password_field.write(password)

    def _agree_to_terms(self, agree):
        checkbox = self._get_terms_checkbox()
        self.move_item_into_view(checkbox)
        if agree:
            checkbox.check()
        else:
            checkbox.uncheck()

    def switch_to_new_account(self):
        new_user_label = self.select_single(objectName='loginFormToggleLabel')
        self.pointing_device.click_object(new_user_label)

    def is_error_label_visible(self):
        error_label = self.select_single(objectName='errorLabel')
        return error_label.visible

    def log_in(self, email, password):
        self._fill_log_in(email, password)
        self._click_continue()

    def enter_twofactor_code(self, twoFactorCode):
        two_factor_text_field = self.select_single(
            TextField, objectName='twoFactorTextField')
        two_factor_text_field.write(twoFactorCode)
        self._click_continue()

    def _fill_log_in(self, email, password):
        self._enter_email(email)
        self._enter_login_password(password)

    def _enter_email(self, email):
        email_text_field = self.select_single(
            TextField, objectName='emailTextField')
        email_text_field.write(email)

    def _enter_login_password(self, password):
        password_text_field = self.select_single(
            TextField, objectName='loginFormPasswordTextField')
        password_text_field.write(password)

    def _click_continue(self):
        continue_button = self.select_single(
            objectName='continueButton', visible=True)
        self.pointing_device.click_object(continue_button)

    def register_new_account(self, email, name, password,
                             password_confirmation, agree_to_terms):
        self.switch_to_new_account()
        self._enter_email(email)
        self._enter_name(name)
        self._enter_password_new_user(password)
        self._enter_password_confirmation(password_confirmation)
        self._agree_to_terms(agree_to_terms)
        self._click_continue()

    def _enter_name(self, name):
        name_text_field = self.select_single(
            TextField, objectName='nameTextField')
        name_text_field.write(name)

    def _dismiss_on_screen_keyboard(self):
        # XXX instead of dismissing the keyboard, the toolkit should take it
        # into account when swiping things into view. See bug #1442733.
        # -- elopio - 2015-02-24
        if platform.model() != 'Desktop':
            get_keyboard()._keyboard.dismiss()


class Main(QQuickFlickable):

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, APP_PATH_ROOT, b'Main')
