# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging

from autopilot import (
    exceptions,
    logging as autopilot_logging
)
from ubuntu_system_tests.helpers.autopilot import validate_dbus_object
from ubuntu_system_tests.helpers.unity8 import (
    greeter as greeter_helpers)

from ubuntu_system_tests.helpers.ubuntuuitools.cpo.common import CustomProxyObjectBase  # NOQA
from ubuntu_system_tests.helpers.unity8.utils import UNITY8_PATH_ROOT

logger = logging.getLogger(__name__)


class Unity8(CustomProxyObjectBase):

    """Autopilot custom proxy object for the Unity8 shell."""

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, UNITY8_PATH_ROOT, UNITY8_PATH_ROOT,
            applicationName='unity8')

    @property
    def main_window(self):
        from ubuntu_system_tests.helpers.unity8.shell_view import ShellView
        return self.select_single(ShellView)

    @autopilot_logging.log_action(logger.debug)
    def wait_for_greeter_content(self):
        greeter = self.main_window.wait_select_single(objectName='greeter')
        greeter.waiting.wait_for(False)

    @autopilot_logging.log_action(logger.info)
    def unlock(self):
        greeter = self.main_window.get_greeter()
        if greeter.created:
            greeter_helpers.hide_greeter_with_dbus()
            greeter.created.wait_for(False)

    def show_dash_from_launcher(self):
        self.main_window.show_dash_from_launcher()

    def get_number_of_surfaces(self):
        application_window = self.select_single('ApplicationWindow')
        return len(application_window.select_many('SurfaceContainer'))

    def get_height(self):
        return self.main_window.height

    def get_width(self):
        return self.main_window.width

    def ensure_app_loaded(self):
        try:
            indicator = self.select_single('ActivityIndicator')
            indicator.onScreen.wait_for(False)
        except exceptions.StateNotFoundError:
            # This is fine, it's already loaded
            pass
