#!/usr/bin/python3

#
# Ubuntu System Tests
# Copyright (C) 2014, 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import os
import subprocess

from ubuntu_system_tests.common import (
    config,
    ssh
)
from ubuntu_system_tests.common.utils import get_tests_ids_to_run
from ubuntu_system_tests.helpers.unity8.utils import (
    ensure_unity_in_required_state
)
from ubuntu_system_tests.systemtests.utils import (
    get_artifacts_directory,
    ensure_keyfile_deleted,
    build_autopilot_command_list,
    append_subunit_results
)


def main():
    artifacts_directory = get_artifacts_directory()
    config_stack = config.get_device_config_stack()
    ssh.prepare_device_keys()

    test_ids = get_tests_ids_to_run()
    result = run_autopilot_tests(config_stack, artifacts_directory, *test_ids)
    ensure_keyfile_deleted()

    if result is False:
        exit(1)


def run_autopilot_tests(config_stack, artifacts_directory, *test_ids):
    """Run autopilot tests. Return True if all tests pass, False otherwise."""
    autopilot_cmd = build_autopilot_command_list(config_stack)

    subunit_destination_file_path = os.path.join(
        artifacts_directory, 'test-results.subunit')

    return_code = 0

    for test_id in test_ids:
        if not test_id.startswith('ubuntu_system_tests'):
            ensure_unity_in_required_state(test_id)
        results_file_path = os.path.join(
            artifacts_directory, test_id + '.subunit')
        test_cmd = autopilot_cmd + ['-o', results_file_path, test_id]
        return_code += subprocess.call(test_cmd)
        if os.path.exists(results_file_path):
            append_subunit_results(
                subunit_destination_file_path, results_file_path)
    return return_code == 0


if __name__ == '__main__':
    main()
