#!/usr/bin/python3

#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import os

from ubuntu_system_tests.common import (
    config,
    ssh
)

DEFAULT_TEST_TIMEOUT = '1200'  # 20 minutes.


def get_artifacts_directory():
    """Returns path to the directory in which results should be written to."""
    return os.environ.get('ADT_ARTIFACTS')


def build_autopilot_command_list(config_stack):
    """Return a list containing the base autopilot command to run."""
    test_config_string = config.get_test_config_values(config_stack)

    return [
        'python3',
        '-m',
        'autopilot.run',
        'run',
        '-v',
        '-f',
        'subunit',
        '--config',
        test_config_string,
        '--test-timeout',
        DEFAULT_TEST_TIMEOUT
    ]


def append_subunit_results(destination_file_path, results_file_path):
    """Append the subunit results into another subunit file."""
    with open(destination_file_path, 'ab') as destination_file:
        with open(results_file_path, 'rb') as results_file:
            destination_file.write(results_file.read())


def ensure_keyfile_deleted():
    """Delete the keypair file after the tests are executed"""
    ssh.ensure_device_keyfile_deleted()
