# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Copyright (C) 2014, 2015 Canonical Ltd.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation; version 3.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

import autopilot
from autopilot.matchers import Eventually
from testtools.matchers import Equals
from testtools import skipUnless
from testtools.matchers import Contains

from ubuntu_system_tests.helpers import bluetooth
from ubuntu_system_tests.helpers import system_settings
from ubuntu_system_tests.helpers.indicators.bluetooth import (
    BluetoothIndicatorPage)
from ubuntu_system_tests.tests import base
from ubuntu_system_tests.tests.indicators.base import IndicatorTestCaseBase

BLUETOOTH_INDICATOR = 'indicator-bluetooth'
BLUETOOTH_INDICATOR_PAGE = 'indicator-bluetooth-page'


class BluetoothTestCase(base.BaseUbuntuSystemTestCase):

    @skipUnless(bluetooth.is_bluetooth_supported(),
                'Bluetooth support required')
    def setUp(self):
        """ Go to Bluetooth page """
        super(BluetoothTestCase, self).setUp()
        self.app = system_settings.launch_system_settings()
        self.bluetooth_page = self.app.go_to_bluetooth_page()

    def test_discover_bluetooth_devices(self):
        """Discover Bluetooth devices.

        The test only runs if the 'bluetooth_device_name' option variable
        has been set

        """
        device_name = autopilot.get_test_configuration().get(
            'bluetooth_device_name', None)
        if device_name:
            self.assertThat(
                lambda: self.bluetooth_page.get_disconnected_devices(),
                Eventually(Contains(device_name), timeout=60)
            )
        else:
            self.skipTest('Bluetooth device not declared to be present')


class BluetoothIndicatorTestCase(IndicatorTestCaseBase):

    @skipUnless(bluetooth.is_bluetooth_supported(),
                'Bluetooth support required')
    def setUp(self):
        super().setUp(BluetoothIndicatorPage.name)

    def test_toggle_bluetooth(self):
        """
        Verify bluetooth toggle works
        1. Drag down bluetooth indicator
        2. Disable bluetooth
        3. Enable bluetooth
        """
        self.indicator_page.disable_bluetooth()
        self.addCleanup(bluetooth.enable_bluetooth)
        self.assertThat(
            self.indicator_page.is_bluetooth_switch_checked(),
            Eventually(Equals(False)))
        self.assertThat(lambda: bluetooth.is_bluetooth_enabled(),
                        Eventually(Equals(False)))

        self.indicator_page.enable_bluetooth()
        self.assertThat(
            self.indicator_page.is_bluetooth_switch_checked(),
            Eventually(Equals(True)))
        self.assertThat(lambda: bluetooth.is_bluetooth_enabled(),
                        Eventually(Equals(True)))
